@@ -10,4 +10,7 @@ PRODUCTIVE_CLASSES = NOUNS + VERBS + ADJECTIVE + (u'Н',)
 
 RU_CASES = (u'им', u'рд', u'дт', u'вн', u'тв', u'пр', u'зв',)
 RU_NUMBERS = (u'ед', u'мн')
-RU_GENDERS = (u'мр', u'жр', u'ср', u'мр-жр')
\ No newline at end of file
+RU_GENDERS = (u'мр', u'жр', u'ср', u'мр-жр')
+RU_PERSONS = (u'1л', u'2л', u'3л')
+RU_TENSES = (u'нст', u'прш', u'буд')
+RU_VOICES = (u'дст', u'стр')
\ No newline at end of file
